<?php
/**
 * The footer for Guto Lite Theme.
 * @package Guto Lite
 * @since 1.0.7
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

$footer_style 		    = guto_lite_option('footer_style');
$copyright_text 		= guto_lite_option('copyright_text');
$footer_columns	 		= guto_lite_option('footer_widget_layout');
$show_footer_top 		= guto_lite_option('show_footer_top');
$shape_image 		    = guto_lite_option('footer_shape_image');

if ($footer_columns == 12) {
    $footer_column = 1;
} elseif ($footer_columns == 6) {
    $footer_column = 2;
} elseif ($footer_columns == 4) {
    $footer_column = 3;
} elseif ($footer_columns == 3) {
    $footer_column = 4;
}

if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')):
    $footer_class   = "footer-area";
    $footer_bottom  = "";
else:
    $footer_class   = "footer-section";
    $footer_bottom  = "mt-0";
endif;

if($footer_style == '1'):
    $footer_class .= " footer-light";
    $footer_bottom .= " footer-bottom-area";
endif;

if($footer_style == '2'):
    $footer_class .= " footer-light";
    $footer_bottom .= " footer-bottom-area bottom-footer-light";
endif;
if($footer_style == '3'):
    $footer_class .= " os-footer-area os-footer-bg-color pt-100";
    $footer_bottom .= " os-copy-right-area os-copy-right-area-bg-color";
endif;

if( $footer_style == '' || $footer_style == '1' || $footer_style == '2' || $footer_style == '3' ) : ?>

    <footer class="<?php echo esc_attr($footer_class); ?>">
    	<?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')): ?>
            <div class="container">
                <div class="row">
                    <?php for ($i = 1; $i <= $footer_column; $i++): ?>
                        <div class="col-lg-<?php echo esc_attr($footer_columns); ?>">
                            <?php
                            if (is_active_sidebar('footer-widget-' . esc_html($i))):
                                dynamic_sidebar('footer-widget-' . esc_html($i));
                            endif;
                            ?>
                        </div>
                    <?php endfor; ?>
                </div>
            </div>
    	<?php endif; ?>

        <div class="<?php echo esc_attr($footer_bottom); ?>">
            <div class="container">
                <div class="row align-items-center">
                    <?php if($copyright_text ): ?>
                        <div class="col-lg-6 col-sm-6 col-md-6">
                            <p><?php echo wp_kses_post( $copyright_text ); ?></p>
                        </div>
                    <?php endif; ?>
                    <div class="col-lg-6 col-sm-6 col-md-6">
                        <?php if( $footer_style == '' || $footer_style == '1' || $footer_style == '2' ) :
                            if( has_nav_menu('footer') ) :
                                wp_nav_menu(
                                    array(
                                        'theme_location' 	=> 'footer',
                                        'menu'            	=> 'footer',
                                        'container'       	=> 'ul',
                                        'fallback_cb'  		=> false,
                                        'menu_class'      	=> 'menu',
                                        'depth'           	=> 1,
                                    )
                                );
                            endif; 
                        elseif( $footer_style == '3' ) : 
                            if( function_exists('guto_lite_option') ) :
                                $social_links   = guto_lite_option('footer_social_links');
                            else:
                                $social_links   = '';
                            endif;
                            if( is_array( $social_links ) && ! empty( $social_links ) ) : ?>
                                <ul class="social-links">
                                    <?php foreach ( $social_links as $index => $item ) : ?>
                                        <li>
                                            <a href="<?php echo esc_url($item['social_url']) ?>" target="_blank">
                                                <i class="<?php echo esc_attr($item['social_icon']) ?>"></i>
                                            </a>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php endif;
                        endif; ?>
                    </div>
                </div>
            </div>
        </div>
        <?php if($shape_image): ?>
            <div class="circle-map"><img src="<?php echo esc_url($shape_image); ?>" alt="<?php esc_attr_e('Circle', 'guto-lite'); ?>"></div>
    	<?php endif; ?>
    </footer>
<?php elseif( $footer_style == '4' ) : ?>
    <!-- Start Restaurant Footer Area -->
    <section class="<?php echo esc_attr($footer_class); ?> restaurant-footer-area pt-100 pb-70">
        <?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')): ?>
            <div class="container">
                <div class="row">
                    <?php for ($i = 1; $i <= $footer_column; $i++): ?>
                        <div class="col-lg-<?php echo esc_attr($footer_columns); ?>">
                            <?php
                            if (is_active_sidebar('footer-widget-' . esc_html($i))):
                                dynamic_sidebar('footer-widget-' . esc_html($i));
                            endif;
                            ?>
                        </div>
                    <?php endfor; ?>
                </div>
            </div>
        <?php endif; ?>
    </section>
    
    <div class="restaurant-copy-right-area">
        <div class="container">
            <?php if($copyright_text ): ?>
                <p><?php echo wp_kses_post( $copyright_text ); ?></p>
            <?php endif; ?>
        </div>
    </div>
<?php elseif( $footer_style == '5' ) : ?>
    <!-- Start NM Footer Area -->
    <div class="nm-footer-area ptb-80">
        <?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')): ?>
            <div class="container">
                <div class="row">
                    <?php for ($i = 1; $i <= $footer_column; $i++): ?>
                        <div class="col-lg-<?php echo esc_attr($footer_columns); ?>">
                            <?php
                            if (is_active_sidebar('footer-widget-' . esc_html($i))):
                                dynamic_sidebar('footer-widget-' . esc_html($i));
                            endif;
                            ?>
                        </div>
                    <?php endfor; ?>
                </div>
            </div>
        <?php endif; ?>
    </div>
    <!-- End NM Footer Area -->

    <!-- Start NM Copy Right Area -->
    <div class="nm-copy-right-area">
        <div class="container">
            <?php if($copyright_text ): ?>
                <p><?php echo wp_kses_post( $copyright_text ); ?></p>
            <?php endif; ?>
        </div>
    </div>

<?php endif;